@@ -15,7 +15,7 @@ def file2speech(fileName, chn=1, sro=None, start=0, end=-1):
     
     if path.isfile(fileName):
         _, ext = path.splitext(fileName)
-        if ext == ".mp3":
+        if ext in [".mp3", ".sph", ".flac"]:
             import librosa
             import warnings
             warnings.filterwarnings('ignore')
